@@ -10,27 +10,27 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.03';
+$VERSION = '0.04';
 $DATE = '2004/05/10';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/File_Maker.pm' => [qw(0.03 2004/05/10), 'revised 0.02'],
-    'MANIFEST' => [qw(0.03 2004/05/10), 'generated, replaces 0.02'],
-    'Makefile.PL' => [qw(0.03 2004/05/10), 'generated, replaces 0.02'],
-    'README' => [qw(0.03 2004/05/10), 'generated, replaces 0.02'],
-    'lib/File/Maker.pm' => [qw(0.03 2004/05/10), 'revised 0.02'],
-    't/File/Maker.d' => [qw(0.02 2004/05/10), 'revised 0.01'],
-    't/File/Maker.pm' => [qw(0.03 2004/05/10), 'revised 0.02'],
-    't/File/Maker.t' => [qw(0.03 2004/05/10), 'revised 0.02'],
+    'lib/Docs/Site_SVD/File_Maker.pm' => [qw(0.04 2004/05/10), 'revised 0.03'],
+    'MANIFEST' => [qw(0.04 2004/05/10), 'generated, replaces 0.03'],
+    'Makefile.PL' => [qw(0.04 2004/05/10), 'generated, replaces 0.03'],
+    'README' => [qw(0.04 2004/05/10), 'generated, replaces 0.03'],
+    'lib/File/Maker.pm' => [qw(0.04 2004/05/10), 'revised 0.03'],
+    't/File/Maker.d' => [qw(0.01 2004/05/10), 'unchanged'],
+    't/File/Maker.pm' => [qw(0.01 2004/05/10), 'unchanged'],
+    't/File/Maker.t' => [qw(0.01 2004/05/10), 'unchanged'],
     't/File/_Maker_/MakerDB.pm' => [qw(0.01 2004/05/10), 'unchanged'],
-    't/File/File/Package.pm' => [qw(1.16 2004/05/10), 'unchanged'],
-    't/File/File/SmartNL.pm' => [qw(1.14 2004/05/10), 'unchanged'],
-    't/File/Test/Tech.pm' => [qw(1.23 2004/05/10), 'revised 1.22'],
-    't/File/Data/Secs2.pm' => [qw(1.21 2004/05/10), 'revised 1.2'],
-    't/File/Data/SecsPack.pm' => [qw(0.06 2004/05/10), 'revised 0.05'],
-    't/File/Data/Startup.pm' => [qw(0.05 2004/05/10), 'revised 0.04'],
+    't/File/File/Package.pm' => [qw(1.17 2004/05/10), 'revised 1.16'],
+    't/File/File/SmartNL.pm' => [qw(1.15 2004/05/10), 'revised 1.14'],
+    't/File/Test/Tech.pm' => [qw(1.24 2004/05/10), 'revised 1.23'],
+    't/File/Data/Secs2.pm' => [qw(1.22 2004/05/10), 'revised 1.21'],
+    't/File/Data/SecsPack.pm' => [qw(0.07 2004/05/10), 'revised 0.06'],
+    't/File/Data/Startup.pm' => [qw(0.06 2004/05/10), 'revised 0.05'],
 
 );
 
@@ -57,9 +57,9 @@ use vars qw(%INVENTORY);
 
  File::Maker - mimics a make by loading a database and calling targets methods
 
- Revision: -
+ Revision: C
 
- Version: 0.03
+ Version: 0.04
 
  Date: 2004/05/10
 
@@ -109,7 +109,7 @@ and macros in a "makefile".
 
 =head2 1.3 Document overview.
 
-This document releases File::Maker version 0.03
+This document releases File::Maker version 0.04
 providing description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -124,7 +124,7 @@ system file specification.
 
 This document releases the file 
 
- File-Maker-0.03.tar.gz
+ File-Maker-0.04.tar.gz
 
 found at the following repository(s):
 
@@ -168,6 +168,21 @@ disclaimer in the documentation and/or
 other materials provided with the
 distribution.
 
+=item 3
+
+Commercial installation of the binary or source
+must visually present to the installer 
+the above copyright notice,
+this list of conditions intact,
+that the original source is available
+at http://softwarediamonds.com
+and provide means
+for the installer to actively accept
+the list of conditions; 
+otherwise, a license fee must be paid to
+Softwareware Diamonds.
+
+
 =back
 
 SOFTWARE DIAMONDS, http://www.SoftwareDiamonds.com,
@@ -196,21 +211,21 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/File_Maker.pm                              0.03    2004/05/10 revised 0.02
- MANIFEST                                                     0.03    2004/05/10 generated, replaces 0.02
- Makefile.PL                                                  0.03    2004/05/10 generated, replaces 0.02
- README                                                       0.03    2004/05/10 generated, replaces 0.02
- lib/File/Maker.pm                                            0.03    2004/05/10 revised 0.02
- t/File/Maker.d                                               0.02    2004/05/10 revised 0.01
- t/File/Maker.pm                                              0.03    2004/05/10 revised 0.02
- t/File/Maker.t                                               0.03    2004/05/10 revised 0.02
+ lib/Docs/Site_SVD/File_Maker.pm                              0.04    2004/05/10 revised 0.03
+ MANIFEST                                                     0.04    2004/05/10 generated, replaces 0.03
+ Makefile.PL                                                  0.04    2004/05/10 generated, replaces 0.03
+ README                                                       0.04    2004/05/10 generated, replaces 0.03
+ lib/File/Maker.pm                                            0.04    2004/05/10 revised 0.03
+ t/File/Maker.d                                               0.01    2004/05/10 unchanged
+ t/File/Maker.pm                                              0.01    2004/05/10 unchanged
+ t/File/Maker.t                                               0.01    2004/05/10 unchanged
  t/File/_Maker_/MakerDB.pm                                    0.01    2004/05/10 unchanged
- t/File/File/Package.pm                                       1.16    2004/05/10 unchanged
- t/File/File/SmartNL.pm                                       1.14    2004/05/10 unchanged
- t/File/Test/Tech.pm                                          1.23    2004/05/10 revised 1.22
- t/File/Data/Secs2.pm                                         1.21    2004/05/10 revised 1.2
- t/File/Data/SecsPack.pm                                      0.06    2004/05/10 revised 0.05
- t/File/Data/Startup.pm                                       0.05    2004/05/10 revised 0.04
+ t/File/File/Package.pm                                       1.17    2004/05/10 revised 1.16
+ t/File/File/SmartNL.pm                                       1.15    2004/05/10 revised 1.14
+ t/File/Test/Tech.pm                                          1.24    2004/05/10 revised 1.23
+ t/File/Data/Secs2.pm                                         1.22    2004/05/10 revised 1.21
+ t/File/Data/SecsPack.pm                                      0.07    2004/05/10 revised 0.06
+ t/File/Data/Startup.pm                                       0.06    2004/05/10 revised 0.05
 
 
 =head2 3.3 Changes
@@ -234,6 +249,47 @@ module.
 Restore C<@INC> in C<load_db> subroutine.
 Added test for the same.
 
+=item File-Maker-0.04
+
+Failures for 0.03:
+
+ Subject: FAIL File-Maker-0.03 i386-netbsd 1.6 
+ Subject: FAIL File-Maker-0.03 sparc-linux 2.4.21-pre7 
+ Subject: FAIL File-Maker-0.03 i386-freebsd 4.6.2-release 
+
+ From: alian@cpan.org (CPAN Tester; CPAN++ automate ) 
+
+ t/File/Maker....# Test 6 got: '
+
+
+ Revision: -^
+ End_User: General Public^
+ Author: http://www.SoftwareDiamonds.com support@SoftwareDiamonds.com^
+ Version: ^
+ Classification: None^
+
+
+ ~-~
+ ' (t/File/Maker.t at line 190)
+ #   Expected: '
+
+
+ Revision: -^
+ End_User: General Public^
+ Author: http://www.SoftwareDiamonds.com support@SoftwareDiamonds.com^
+ Version: ^
+ Classification: None^
+
+
+ ~-~
+ '
+
+CORRECTIVE:
+
+Probably differences in New Line for Unix versus Microsoft. Thus, run
+the C<__DATA__> through the smartNL routine to see if File-Maker has
+a better reception in the UNIX world.
+
 =back
 
 =head2 3.4 Adaptation data.
@@ -272,13 +328,13 @@ Enter one of the following repositories in a web browser:
   http://www.softwarediamonds/packages/
   http://www.perl.com/CPAN/authors/id/S/SO/SOFTDIA/
 
-Right click on 'File-Maker-0.03.tar.gz' and download to a temporary
+Right click on 'File-Maker-0.04.tar.gz' and download to a temporary
 installation directory.
 Enter the following where $make is 'nmake' for microsoft
 windows; otherwise 'make'.
 
- gunzip File-Maker-0.03.tar.gz
- tar -xf File-Maker-0.03.tar
+ gunzip File-Maker-0.04.tar.gz
+ tar -xf File-Maker-0.04.tar
  perl Makefile.PL
  $make test
  $make install
@@ -384,11 +440,11 @@ DISTNAME:
 File-Maker^
 REPOSITORY_DIR: packages^
 
-VERSION : 0.03^
+VERSION : 0.04^
 FREEZE: 1^
 PREVIOUS_DISTNAME:  ^
-PREVIOUS_RELEASE: 0.02^
-REVISION: -^
+PREVIOUS_RELEASE: 0.03^
+REVISION: C^
 
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
 
@@ -458,6 +514,47 @@ module.
 Restore C<@INC> in C<load_db> subroutine.
 Added test for the same.
 
+\=item File-Maker-0.04
+
+Failures for 0.03:
+
+ Subject: FAIL File-Maker-0.03 i386-netbsd 1.6 
+ Subject: FAIL File-Maker-0.03 sparc-linux 2.4.21-pre7 
+ Subject: FAIL File-Maker-0.03 i386-freebsd 4.6.2-release 
+
+ From: alian@cpan.org (CPAN Tester; CPAN++ automate ) 
+
+ t/File/Maker....# Test 6 got: '
+
+
+ Revision: -^^
+ End_User: General Public^^
+ Author: http://www.SoftwareDiamonds.com support@SoftwareDiamonds.com^^
+ Version: ^^
+ Classification: None^^
+
+
+ ~--~
+ ' (t/File/Maker.t at line 190)
+ #   Expected: '
+
+
+ Revision: -^^
+ End_User: General Public^^
+ Author: http://www.SoftwareDiamonds.com support@SoftwareDiamonds.com^^
+ Version: ^^
+ Classification: None^^
+
+
+ ~--~
+ '
+
+CORRECTIVE:
+
+Probably differences in New Line for Unix versus Microsoft. Thus, run
+the C<__DATA__> through the smartNL routine to see if File-Maker has
+a better reception in the UNIX world.
+
 \=back
 
 ^
@@ -517,6 +614,21 @@ disclaimer in the documentation and/or
 other materials provided with the
 distribution.
 
+\=item 3
+
+Commercial installation of the binary or source
+must visually present to the installer 
+the above copyright notice,
+this list of conditions intact,
+that the original source is available
+at http://softwarediamonds.com
+and provide means
+for the installer to actively accept
+the list of conditions; 
+otherwise, a license fee must be paid to
+Softwareware Diamonds.
+
+
 \=back
 
 SOFTWARE DIAMONDS, http://www.SoftwareDiamonds.com,
@@ -652,5 +764,9 @@ HTML:
 
 
 
+
+
+
+
 
 
